pub struct DeviceStatus {Show 17 fields
pub interface: String,
pub receive_bytes: u64,
pub receive_packets: u64,
pub receive_errs: u64,
pub receive_drop: u64,
pub receive_fifo: u64,
pub receive_frame: u64,
pub receive_compressed: u64,
pub receive_multicast: u64,
pub transmit_bytes: u64,
pub transmit_packets: u64,
pub transmit_errs: u64,
pub transmit_drop: u64,
pub transmit_fifo: u64,
pub transmit_colls: u64,
pub transmit_carrier: u64,
pub transmit_compressed: u64,
}Expand description
Network device status information.
See man 5 proc and Linux/net/core/net-procfs.c
Fields
interface: StringName of the interface representing this device.
receive_bytes: u64Number of received bytes.
receive_packets: u64Number of received packets.
receive_errs: u64Number of bad packets received.
receive_drop: u64Number of incoming packets dropped.
receive_fifo: u64Number of incoming packets dropped due to fifo overrun.
receive_frame: u64Number of incoming packets dropped due to frame alignment errors.
receive_compressed: u64Number of CSLIP packets received.
receive_multicast: u64Number of multicast packets received.
transmit_bytes: u64Number of transmitted bytes.
transmit_packets: u64Number of transmitted packets.
transmit_errs: u64Number of occurred transmission problems.
transmit_drop: u64Number of outgoing packets dropped.
transmit_fifo: u64Number of outgoing packets dropped due to fifo overrun.
transmit_colls: u64Number of occurred packet collisions.
transmit_carrier: u64Number of occurred carrier errors.
transmit_compressed: u64Number of CSLIP packets transmitted.